Author: Jean-Philippe Meuret
Keywords: distance, sampling, mcds, full, ACDC, Cournols, Olloix, 2019, Distance Sampling, Naturalist, smartphone, auto-filter

ACDC 2019 Naturalist
Auto-filtered report: "ExAicMQua-r925m8q3d12" method
Estimation of common breeding bird populations on the Cournols - Olloix plateau - in 2019 though ~100 distance sampling point transects of 5 and 10mn (2 seasonal passes) ; using the Naturalist smartphone app. for field surveys
Warning: This is only an extract of the actual report, limited to 1 species and the best 3 analyses for it

#### Table of contents

- Results: the essence
- Results: main figures
- Results: all details
- Traceability

## Results: the essence

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Confidence value interval: If not listed in table below, please note that ALL analyses have been run with the same value: 95 .

Adjustment term selection criterion: If not listed in table below, please note that ALL analyses have been run with the same value: AIC .

Note: Most figures have been rounded for readability, but 'CoefVar Density' have been further modified : converted to %

Click on analysis number to get to detailed report

| Sample & Model | Results (1/2) | Results (2/2) | Quantile-quantile plot | Detection probability density (PDF) | Detection probability
--- | --- | --- | --- | --- | --- | ---
13 |
Echant | 1
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 403
Max Dist | 511.41
Mod Key Fn | HAZARD
Mod Adj Ser | POLY
Left Trunc Dist | 5
Right Trunc Dist | 492
Fit Dist Cuts | 13
Analyse | 49
ExCod | 1
Effort | 190
NObs | 401
Obs Rate | 99.5
NumPars AdjSer | 0
AIC | 4488.2
Chi2 P | 0.25
KS P | 0.55
CoefVar Density | 10
Qual Bal 3 | 0.65
Qual Bal 2 | 0.64
Qual Bal 1 | 0.65
Density | 37.58
Min Density | 30.87
Max Density | 45.75
Number | 902
Min Number | 741
Max Number | 1098
EDR/ESW | 133.7
PDetec | 0.074
14 |
Echant | 1
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 403
Max Dist | 511.41
Mod Key Fn | HAZARD
Mod Adj Ser | POLY
Left Trunc Dist |
Right Trunc Dist |
Fit Dist Cuts | 13
Analyse | 43
ExCod | 1
Effort | 190
NObs | 403
Obs Rate | 100
NumPars AdjSer | 0
AIC | 4526.8
Chi2 P | 0.16
KS P | 0.52
CoefVar Density | 9.9
Qual Bal 3 | 0.6
Qual Bal 2 | 0.59
Qual Bal 1 | 0.6
Density | 36.95
Min Density | 30.45
Max Density | 44.85
Number | 887
Min Number | 731
Max Number | 1076
EDR/ESW | 135.2
PDetec | 0.07
15 |
Echant | 1
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 403
Max Dist | 511.41
Mod Key Fn | HAZARD
Mod Adj Ser | POLY
Left Trunc Dist | 6
Right Trunc Dist |
Fit Dist Cuts | 25
Analyse | 47
ExCod | 1
Effort | 190
NObs | 402
Obs Rate | 99.8
NumPars AdjSer | 0
AIC | 4507.1
Chi2 P | 0.1
KS P | 0.52
CoefVar Density | 9.9
Qual Bal 3 | 0.56
Qual Bal 2 | 0.56
Qual Bal 1 | 0.56
Density | 36.93
Min Density | 30.4
Max Density | 44.86
Number | 886
Min Number | 730
Max Number | 1077
EDR/ESW | 135
PDetec | 0.07

## Results: main figures

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Confidence value interval: If not listed in table below, please note that ALL analyses have been run with the same value: 95 .

Adjustment term selection criterion: If not listed in table below, please note that ALL analyses have been run with the same value: AIC .

Note: Most figures have been rounded for readability, but 'CoefVar Density' have been further modified : converted to %

Click on analysis number to get to detailed report

| Echant | Espèce | Passage | Adulte | Durée | NTot Obs | Max Dist | Analyse | Mod Key Fn | Mod Adj Ser | Left Trunc Dist | Right Trunc Dist | Fit Dist Cuts | ExCod | Effort | NObs | Obs Rate | NumPars AdjSer | Delta AIC | Chi2 P | KS P | CvM Uw P | CvM Cw P | CoefVar Density | Final selection | Pre-selection Qual Bal 3 | Qual Bal 3 | Pre-selection Qual Bal 2 | Qual Bal 2 | Pre-selection Qual Bal 1 | Qual Bal 1 | Qual Chi2+ | Qual KS+ | Qual DCv+ | Density | Min Density | Max Density | Number | Min Number | Max Number | EDR/ESW | Min EDR/ESW | Max EDR/ESW | PDetec | Min PDetec | Max PDetec | RunFolder
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
13 | 1 | Sylvia atricapilla | a+b | m | 10mn | 403 | 511.41 | 49 | HAZARD | POLY | 5 | 492 | 13 | 1 | 190 | 401 | 99.5 | 0 | 0 | 0.25 | 0.55 | 0.6 | 0.7 | 10 |  | 1 | 0.65 | 1 | 0.64 | 1 | 0.65 | 0.58 | 0.64 | 0.67 | 37.58 | 30.87 | 45.75 | 902 | 741 | 1098 | 133.7 | 124.4 | 143.6 | 0.074 | 0.064 | 0.085 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma-90vq_6nr
14 | 1 | Sylvia atricapilla | a+b | m | 10mn | 403 | 511.41 | 43 | HAZARD | POLY |  |  | 13 | 1 | 190 | 403 | 100 | 0 | 0 | 0.16 | 0.52 | 0.6 | 0.6 | 9.9 |  | 2 | 0.6 | 2 | 0.59 | 2 | 0.6 | 0.52 | 0.59 | 0.63 | 36.95 | 30.45 | 44.85 | 887 | 731 | 1076 | 135.2 | 126 | 144.9 | 0.07 | 0.061 | 0.08 | SylvAtri-ab-10mn-m-haz-pol-ma-w3hq64b3
15 | 1 | Sylvia atricapilla | a+b | m | 10mn | 403 | 511.41 | 47 | HAZARD | POLY | 6 |  | 25 | 1 | 190 | 402 | 99.8 | 0 | 0 | 0.1 | 0.52 | 0.6 | 0.6 | 9.9 |  | 3 | 0.56 | 3 | 0.56 | 3 | 0.56 | 0.47 | 0.56 | 0.59 | 36.93 | 30.4 | 44.86 | 886 | 730 | 1077 | 135 | 125.9 | 144.9 | 0.07 | 0.061 | 0.08 | SylvAtri-ab-10mn-m-haz-pol-la-ma-7ak3cu9l

## Results: all details

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Note: All values have been left untouched, as output by MCDS (no rounding, no conversion)

Click on analysis number to get to detailed report

| Analyse | Echant | Espèce | Passage | Adulte | Durée | FonctionClé | SérieAjust | TrGche | TrDrte | NbTrchMod | Abrev. Analyse | OptimTrunc | NTot Obs | Min Dist | Max Dist | Mod Key Fn | Mod Adj Ser | Mod Chc Crit | Conf Interv | Left Trunc Dist | Right Trunc Dist | Fit Dist Cuts | ExCod | StartTime | ElapsedTime | RunFolder | NObs | NSamp | Effort | EncRate | CoefVar EncRate | Min EncRate | Max EncRate | DoF EncRate | Left Trunc | Right Trunc | Obs Rate | TotNum Pars | Delta AIC | AIC | Chi2 P | Chi2 P 1 | Chi2 P 2 | Chi2 P 3 | f/h(0) | CoefVar f/h(0) | Min f/h(0) | Max f/h(0) | DoF f/h(0) | PDetec | CoefVar PDetec | Min PDetec | Max PDetec | DoF PDetec | EDR/ESW | CoefVar EDR/ESW | Min EDR/ESW | Max EDR/ESW | DoF EDR/ESW | AICc | BIC | LogLhood | KS P | CvM Uw P | CvM Cw P | Key Fn | Adj Ser | NumPars KeyFn | NumPars AdjSer | Num Covars | EstA(1) | EstA(2) | EstA(3) | DensClu | CoefVar DensClu | Min DensClu | Max DensClu | DoF DensClu | Density | Delta CoefVar Density | CoefVar Density | Min Density | Max Density | DoF Density | Number | CoefVar Number | Min Number | Max Number | DoF Number | Pre-selection Qual Bal 1 | Qual Bal 1 | Pre-selection Qual Bal 2 | Qual Bal 2 | Final selection | Pre-selection Qual Bal 3 | Qual Bal 3 | Qual Chi2+ | Qual KS+ | Qual DCv+ | Group Left Trunc | Group Right Trunc | Order Same Trunc AIC | Order Close Trunc Chi2 KS DCv | Order Close Trunc DCv | Order Close Trunc Bal 1 Qual | Order Close Trunc Bal 2 Qual | Order Close Trunc Bal 3 Qual | Order Close Trunc Bal Chi2+ Qual | Order Close Trunc Bal KS+ Qual | Order Close Trunc Bal DCv+ Qual | Order Global Chi2 KS DCv | Order Global Bal 1 Qual | Order Global Bal 2 Qual | Order Global Bal 3 Qual | Order Global Bal Chi2+ Qual | Order Global Bal KS+ Qual | Order Global Bal DCv+ Qual | Order Global DeltaAIC Chi2 KS DCv
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
13 | 49 | 1 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 4.553960 | 492.328316 | 13.000000 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma | 1 | 403 | 1.212094 | 511.409745 | HAZARD | POLY | AIC | 95 | 4.553960 | 492.328316 | 13.000000 | 1 | 2023-04-30 15:55:03.377000 | 1.300000 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma-90vq_6nr | 401 | 96 | 190 | 2.110526 | 0.068677 | 1.841824 | 2.418429 | 95 | 4.553960 | 492.328000 | 99.503722 | 2.000000 | 0.000000 | 4488.174000 | 0.250081 | 0.250081 | nan | nan | 0.000112 | 0.073005 | 0.000097 | 0.000129 | 399.000000 | 0.073743 | 0.073005 | 0.063896 | 0.085108 | 399.000000 | 133.695000 | 0.036502 | 124.440000 | 143.638200 | 399.000000 | 4488.205000 | 4496.162000 | -2242.087000 | 0.550075 | 0.600000 | 0.700000 | HAZARD | POLY | 2.000000 | 0.000000 | 0.000000 | 99.033550 | 3.760158 | nan | 37.584680 | 0.100231 | 30.874110 | 45.753800 | 330.520400 | 37.584680 | 0.000000 | 0.100231 | 30.874110 | 45.753800 | 330.520400 | 902 | 0.100231 | 741 | 1098 | 330.520400 | 1.000000 | 0.653611 | 1.000000 | 0.640192 | nan | 1.000000 | 0.648279 | 0.583173 | 0.636554 | 0.672710 | 1 | 4 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 1 | 0 | 0 | 0 | 0 | 0 | 0 | 13
14 | 43 | 1 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | nan | nan | 13.000000 | SylvAtri-ab-10mn-m-haz-pol-ma | 1 | 403 | 1.212094 | 511.409745 | HAZARD | POLY | AIC | 95 | nan | nan | 13.000000 | 1 | 2023-04-30 15:55:03.259000 | 0.854000 | SylvAtri-ab-10mn-m-haz-pol-ma-w3hq64b3 | 403 | 96 | 190 | 2.121053 | 0.068384 | 1.852082 | 2.429085 | 95 | 0.000000 | 511.409800 | 100.000000 | 2.000000 | 0.000000 | 4526.764000 | 0.163355 | 0.163355 | nan | nan | 0.000109 | 0.071058 | 0.000095 | 0.000126 | 401.000000 | 0.069854 | 0.071058 | 0.060758 | 0.080313 | 401.000000 | 135.165300 | 0.035529 | 126.049500 | 144.940400 | 401.000000 | 4526.793000 | 4534.762000 | -2261.382000 | 0.517396 | 0.600000 | 0.600000 | HAZARD | POLY | 2.000000 | 0.000000 | 0.000000 | 100.793500 | 3.829198 | nan | 36.954800 | 0.098619 | 30.451850 | 44.846450 | 321.971000 | 36.954800 | 0.016817 | 0.098619 | 30.451850 | 44.846450 | 321.971000 | 887 | 0.098619 | 731 | 1076 | 321.971000 | 2.000000 | 0.597147 | 2.000000 | 0.591720 | nan | 2.000000 | 0.599049 | 0.518512 | 0.589375 | 0.627415 | 0 | 0 | 0 | 0 | 1 | 0 | 0 | 0 | 0 | 0 | 0 | 4 | 2 | 2 | 2 | 2 | 2 | 2 | 2
15 | 47 | 1 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 6.391710 | nan | 25.000000 | SylvAtri-ab-10mn-m-haz-pol-la-ma | 1 | 403 | 1.212094 | 511.409745 | HAZARD | POLY | AIC | 95 | 6.391710 | nan | 25.000000 | 1 | 2023-04-30 15:55:03.337000 | 1.184997 | SylvAtri-ab-10mn-m-haz-pol-la-ma-7ak3cu9l | 402 | 96 | 190 | 2.115789 | 0.068798 | 1.845974 | 2.425042 | 95 | 6.391710 | 511.409800 | 99.751861 | 2.000000 | 0.000000 | 4507.106000 | 0.101200 | 0.101200 | nan | nan | 0.000110 | 0.071378 | 0.000095 | 0.000126 | 400.000000 | 0.069735 | 0.071378 | 0.060616 | 0.080225 | 400.000000 | 135.049600 | 0.035689 | 125.901800 | 144.861900 | 400.000000 | 4507.137000 | 4515.100000 | -2251.553000 | 0.516043 | 0.600000 | 0.600000 | HAZARD | POLY | 2.000000 | 0.000000 | 0.000000 | 100.828300 | 3.829837 | nan | 36.926330 | 0.099136 | 30.397570 | 44.857340 | 321.199400 | 36.926330 | 0.000000 | 0.099136 | 30.397570 | 44.857340 | 321.199400 | 886 | 0.099136 | 730 | 1077 | 321.199400 | 3.000000 | 0.557162 | 3.000000 | 0.556845 | nan | 3.000000 | 0.563787 | 0.465836 | 0.558271 | 0.594383 | 1 | 0 | 0 | 0 | 1 | 0 | 0 | 0 | 0 | 0 | 0 | 7 | 4 | 5 | 5 | 5 | 5 | 4 | 14

## Traceability

### Filter and sort steps

|  | Property | Value
--- | --- | --- | ---
Scheme | Step |  |
ExAicMQua-r925m8q3d12 | before | datetime | 2023-04-30 16:23:28.325893
before | results | 272
run status | column | ExCod
run status | max value | 2
run status | results | 272
duplicates on params | param. names | Echant, NObs, Effort, Delta AIC, Chi2 P, KS P, CvM Uw P, CvM Cw P, CoefVar Density, PDetec, Min PDetec, Max PDetec, Density, Min Density, Max Density
duplicates on params | param. precisions | Delta AIC: 1, Chi2 P: 2, KS P: 2, CvM Uw P: 2, CvM Cw P: 2, CoefVar Density: 2, PDetec: 3, Min PDetec: 3, Max PDetec: 3, Density: 2, Min Density: 2, Max Density: 2
duplicates on params | results | 262
best AIC | column | Order Same Trunc AIC
best AIC | upper limit (excluded) | 3
best AIC | results | 262
best results for >= 1 indicator | selected indicator orders | Order Close Trunc Chi2 KS DCv, Order Close Trunc DCv, Qual Bal 3, Qual Bal 2, Qual Bal 1, Order Close Trunc Bal Chi2+ Qual, Order Close Trunc Bal KS+ Qual, Order Close Trunc Bal DCv+ Qual
best results for >= 1 indicator | order limit (excluded) / indicator | 1
best results for >= 1 indicator | results | 262
non-outlier sightings | min sighting rate | 92.5
non-outlier sightings | results | 128
final best results | column | Qual Bal 3
final best results | lower is better ? | False
final best results | max results | 12
final best results | results | 97
final sorting | columns | Left Trunc Dist, Right Trunc Dist, Qual Bal 3
final sorting | lower last column is better ? | False
after | results | 97
auto-preselection | Nb of pre-selections | 5
auto-preselection | pre-selection column | Qual Bal 3
auto-preselection | lower is better ? | False
auto-preselection | eliminating threshold | 0.2
auto-preselection | pre-selection column | Qual Bal 2
auto-preselection | lower is better ? | False
auto-preselection | eliminating threshold | 0.2
auto-preselection | pre-selection column | Qual Bal 1
auto-preselection | lower is better ? | False
auto-preselection | eliminating threshold | 0.2

### Samples

| Espèce | Passage | Adulte | Durée
--- | --- | --- | --- | ---
Echant |  |  |  |
1 | Sylvia atricapilla | a+b | m | 10mn

### Analyses

| Analyse | Espèce | Passage | Adulte | Durée | FonctionClé | SérieAjust | TrGche | TrDrte | NbTrchMod | Abrev. Analyse | Echant | OptimTrunc
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
26 | 28 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  |  |  | SylvAtri-ab-10mn-m-hno-pol | 1 | 0
27 | 29 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  |  | 18.0 | SylvAtri-ab-10mn-m-hno-pol-ma | 1 | 1
28 | 30 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  | 304.252039 |  | SylvAtri-ab-10mn-m-hno-pol-ra | 1 | 1
29 | 31 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  | 348.521960 | 13.0 | SylvAtri-ab-10mn-m-hno-pol-ra-ma | 1 | 1
30 | 32 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 16.444080 |  |  | SylvAtri-ab-10mn-m-hno-pol-la | 1 | 1
31 | 33 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 15.626942 |  | 14.0 | SylvAtri-ab-10mn-m-hno-pol-la-ma | 1 | 1
32 | 34 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 16.270027 | 310.198495 |  | SylvAtri-ab-10mn-m-hno-pol-la-ra | 1 | 1
33 | 35 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 22.018688 | 295.120411 | 13.0 | SylvAtri-ab-10mn-m-hno-pol-la-ra-ma | 1 | 1
34 | 37 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  | 100.000000 |  | SylvAtri-ab-10mn-m-hno-pol-r100 | 1 | 0
35 | 38 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY |  | 200.000000 |  | SylvAtri-ab-10mn-m-hno-pol-r200 | 1 | 0
36 | 39 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 20.000000 |  |  | SylvAtri-ab-10mn-m-hno-pol-l20 | 1 | 0
37 | 40 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 20.000000 | 100.000000 |  | SylvAtri-ab-10mn-m-hno-pol-l20-r100 | 1 | 0
38 | 41 | Sylvia atricapilla | a+b | m | 10mn | HNORMAL | POLY | 20.000000 | 200.000000 |  | SylvAtri-ab-10mn-m-hno-pol-l20-r200 | 1 | 0
39 | 42 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  |  |  | SylvAtri-ab-10mn-m-haz-pol | 1 | 0
40 | 43 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  |  | 13.0 | SylvAtri-ab-10mn-m-haz-pol-ma | 1 | 1
41 | 44 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  | 356.631551 |  | SylvAtri-ab-10mn-m-haz-pol-ra | 1 | 1
42 | 45 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  | 278.003632 | 25.0 | SylvAtri-ab-10mn-m-haz-pol-ra-ma | 1 | 1
43 | 46 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 1.394174 |  |  | SylvAtri-ab-10mn-m-haz-pol-la | 1 | 1
44 | 47 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 6.391710 |  | 25.0 | SylvAtri-ab-10mn-m-haz-pol-la-ma | 1 | 1
45 | 48 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 26.120137 | 265.004829 |  | SylvAtri-ab-10mn-m-haz-pol-la-ra | 1 | 1
46 | 49 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 4.553960 | 492.328316 | 13.0 | SylvAtri-ab-10mn-m-haz-pol-la-ra-ma | 1 | 1
47 | 51 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  | 100.000000 |  | SylvAtri-ab-10mn-m-haz-pol-r100 | 1 | 0
48 | 52 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY |  | 200.000000 |  | SylvAtri-ab-10mn-m-haz-pol-r200 | 1 | 0
49 | 53 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 20.000000 |  |  | SylvAtri-ab-10mn-m-haz-pol-l20 | 1 | 0
50 | 54 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 20.000000 | 100.000000 |  | SylvAtri-ab-10mn-m-haz-pol-l20-r100 | 1 | 0
51 | 55 | Sylvia atricapilla | a+b | m | 10mn | HAZARD | POLY | 20.000000 | 200.000000 |  | SylvAtri-ab-10mn-m-haz-pol-l20-r200 | 1 | 0

### Analyser

| Value
--- | ---
Zone | ACDC
Surface | 24
distanceUnit | Meter
areaUnit | Sq. Kilometer
runMethod | subprocess.run
runTimeOut | 300
surveyType | Point
distanceType | Radial
clustering | False
defEstimKeyFn | HNORMAL
defEstimAdjustFn | COSINE
defEstimCriterion | AIC
defCVInterval | 95
defMinDist |
defMaxDist |
defFitDistCuts |
defDiscrDistCuts |
defExpr2Optimise | balq3
defMinimiseExpr | False
dDefOptimCoreParamsCore | zoopt
dDefOptimCoreParamsMaxIters | 150
dDefOptimCoreParamsTermExprValue |
dDefOptimCoreParamsAlgorithm | racos
dDefOptimCoreParamsMaxRetries | False
defSubmitTimes | 1
defSubmitOnlyBest | 1
defOutliersMethod | tucquant
defOutliersQuantCutPct | 5
defFitDistCutsFctrMin | 0.666667
defFitDistCutsFctrMax | 1.5
defDiscrDistCutsFctrMin | 0.333333
defDiscrDistCutsFctrMax | 1

### Computing platform

| Version
--- | ---
os | Windows Enterprise 10.0.19041 (64bit)
processor | Intel64 Family 6 Model 165 Stepping 2, GenuineIntel, 12 CPUs
python | cpython (win32) R3.8.2 | packaged by conda-forge | (default, Apr 24 2020, 07:34:03) [MSC v.1916 64 bit (AMD64)]
numpy | 1.23.2
pandas | 1.2.5
zoopt | 0.4.0
matplotlib | 3.4.2
jinja2 | 3.0.1
pyaudisam | 1.0.0
DS engine | C:/PortableApps/Distance 7/MCDS.exe

###### Generated on 30/04/2023 16:27:14 with Python 3.8.2, NumPy 1.23.2, Pandas 1.2.5, ZOOpt 0.4.0, Matplotlib 3.4.2, Jinja 3.0.1 ... and PyAuDiSam 1.0.0, with icons from Font Awesome (sources : acdc-2019-nat-ds-params.py, ) .